@@ -552,7 +552,7 @@ class Install(MethodsInterface):
         """
         migrator = migrate(target.getDirectory())
 
-        if not migrator.migrate([[x[0],x[2],x[3]] for x in migrate_data],
+        if not migrator.migrate([[x[0],x[2],x[3]] for x in migrate_data if x],
                                 root_pwd, [], [], ):
             raise InstallError(_("Failed to migrate users onto the new system"))
         return True
